==> vdkxdb_0.0.4.orig.tar.gz: vdkxdb-0.0.4/src/vdkxcheckbutton.cc <==
/*
 * ===========================
 * VDK Visual Development Kit
 * xdb subsystem
 * Version 0.1
 * Revision 0.0
 * April 2000
 * ===========================
 *
 * Copyright (C) 1998, Mario Motta
 * Developed by Mario Motta <mmotta@guest.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <vdkxdb/vdkxcheckbutton.h>


VDKXCheckButton::VDKXCheckButton(VDKForm* owner, 
				 char* label = (char*) NULL, 
				 char* tip = (char*) NULL):
  VDKCheckButton(owner,label,tip), VDKXControl()
{
}

bool 
VDKXCheckButton::AssignTableField(VDKXTable* t,
			    char* fname)
{
  if(t)
    {
      xbShort id = t->GetFieldNo(fname);
      xbShort type = t->GetFieldType(id);
      if((type == 'L') )
	return VDKXControl::AssignTableField(t, fname);
      else
	return false;
    }
  else
    return false;
}
/*
 */
xbShort
VDKXCheckButton::Read()
{
  xbShort rc = XB_NOT_OPEN; 
  if(table)
    {
      rc = table->GetLogicalField(field_id);
      Checked = rc == 1;
    }
  return rc;
}
/*
 */
xbShort
VDKXCheckButton::Write()
{
  xbShort rc = XB_NOT_OPEN; 
  if(table)
	  rc = table->PutField(field_id, Checked ? "Y" : "N");
  return rc;
}

==> vdkxdb2_2.0.2.orig.tar.gz: vdkxdb-2.0.2/src/vdkxcheckbutton.cc <==
/*
 * ===========================
 * VDK Visual Development Kit
 * xdb subsystem
 * Version 0.1
 * Revision 0.0
 * April 2000
 * ===========================
 *
 * Copyright (C) 1998, Mario Motta
 * Developed by Mario Motta <mmotta@guest.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <vdkxdb2/vdkxcheckbutton.h>


VDKXCheckButton::VDKXCheckButton(VDKForm* owner, char* label, char* tip ):
  VDKCheckButton(owner,label,tip), VDKXControl()
{
}

bool 
VDKXCheckButton::AssignTableField(VDKXTable* t,
			    char* fname)
{
  if(t)
    {
      xbShort id = t->GetFieldNo(fname);
      xbShort type = t->GetFieldType(id);
      if((type == 'L') )
	return VDKXControl::AssignTableField(t, fname);
      else
	return false;
    }
  else
    return false;
}
/*
 */
xbShort
VDKXCheckButton::Read()
{
  xbShort rc = XB_NOT_OPEN; 
  if(table)
    {
      rc = table->GetLogicalField(field_id);
      Checked = rc == 1;
    }
  return rc;
}
/*
 */
xbShort
VDKXCheckButton::Write()
{
  xbShort rc = XB_NOT_OPEN; 
  if(table)
	  rc = table->PutField(field_id, Checked ? "Y" : "N");
  return rc;
}
